ArchimedeaMission class

Data containing a Deep Archimedea mission information.

Annotations
  • @JsonSerializable.new()

Constructors

ArchimedeaMission({required String mission, required Modifier deviation, required List<Modifier> riskVariables})
Data containing a Deep Archimedea mission information.
ArchimedeaMission.fromJson(Map<String, dynamic> json)
Creates a ArchimedeaMission from Json map
factory

Properties

deviation Modifier
Mission deviation
final
hashCode int
The hash code for this object.
no setterinherited
mission String
Mission type
final
riskVariables List<Modifier>
Mission risk variables
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Creates a Json map from a ArchimedeaMission
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited