Component class

Components needs to build BuildableItems.

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

Component({required String uniqueName, required String name, required String? description, required bool tradable, required List<Drop>? drops, required int itemCount, String? imageName})
Components needs to build BuildableItems.
const
Component.fromJson(Map<String, dynamic> json)
Creates Component from json map.
factory

Properties

category String
Item category.
finalinherited
description String?
Item decription.
finalinherited
drops List<Drop>?
List of drop ItemCommon locations.
finalinherited
excludeFromCodex bool?
Whether the item is excluded from the codex or not.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
imageName String?
Item image name.
finalinherited
itemCount int
Total require ItemCommon for the blueprint reciepe.
final
name String
Name of the item.
finalinherited
patchlogs List<Patchlog>?
Item changes throughout game version.
finalinherited
probability num?
Chances of the ItemCommon dropping.
finalinherited
productCategory String?
Item product category.
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
rarity Rarity?
ItemCommon rarity.
finalinherited
releaseDate String?
The date the item was released in game.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tradable bool
Whether this item is tradable or not.
finalinherited
type ItemType
Item type.
finalinherited
uniqueName String
Unique name used within the game.
finalinherited
wikiaThumbnail String?
Wikia Item thumbnail url.
finalinherited
wikiaUrl String?
Item wikia url.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Creates a json map from Component.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited