EarthCycle class

Data on the current Earth cycle.

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

EarthCycle({required String id, required DateTime activation, required DateTime expiry, required bool isDay, required EarthState state})
Data on the current Earth cycle.
const
EarthCycle.fromJson(Map<String, dynamic> json)
Creates a EarthCycle from Json map
factory

Properties

activation DateTime
The time the state was activated.
no setteroverride
expiry DateTime
The time the state will expire.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
id String
ID of the instance.
no setteroverride
isDay bool
Whether it is currently day or night on earth.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
remaining Duration?
The remaining time until the state expires.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state EarthState
The current state on earth.
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Creates a Json map from a EarthCycle
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited