name property

String name
final

Name of the item.

This name is reflected of the name seen in-game. uniqueName on he other are the names of the item used internally by game files.

Implementation

final String name;