ItemNotFound class

Item exceptions thrown when an item was not found.

Implemented types

Constructors

ItemNotFound(String name)
Item exceptions thrown when an item was not found.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Item name or uniqueName.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited