Melee class

Represents a Melee weapon

Inheritance
Implementers
Annotations
  • @JsonSerializable.new()

Constructors

Melee({required String uniqueName, required String name, required String? description, required ItemType type, required String category, required String? productCategory, required bool tradable, required String? imageName, required bool? excludeFromCodex, required num criticalChance, required num criticalMultiplier, required List<num> damagePerShot, required int? disposition, required num fireRate, required double omegaAttenuation, required List<String>? polarities, required double procChance, required int? slot, required num totalDamage, required int maxLevelCap, required double? followThrough, required int? heavyAttackDamage, required int? heavySlamAttack, required int? heavySlamRadialDamage, required int? heavySlamRadius, required int? slamAttack, required int? slamRadialDamage, required int? slamRadius, required int? slideAttack, required double? windUp, required double? range, required List<MeleeAttack>? attacks, required Damage? damage, required String? stancePolarity, required List<Patchlog>? patchlogs, required String? releaseDate, required String? wikiaThumbnail, required String? wikiaUrl, required List<String>? tags})
Represents a Melee weapon
const
Melee.fromJson(Map<String, dynamic> data)
Creates a Melee from Json map
factory

Properties

attacks List<Attack>?
Weapon secondary attacks.
finalinherited
category String
Item category.
finalinherited
criticalChance num
Weapon critical chance.
finalinherited
criticalMultiplier num
Weapon critical multiplier.
finalinherited
damage Damage?
Weapon damage.
finalinherited
damagePerShot List<num>
Weapon damage per shot.
finalinherited
description String?
Item decription.
finalinherited
disposition int?
Weapon's riven disposition.
finalinherited
excludeFromCodex bool?
Whether the item is excluded from the codex or not.
finalinherited
fireRate num
Weapon rate of fite.
finalinherited
followThrough double?
Follow through.
final
hashCode int
The hash code for this object.
no setterinherited
heavyAttackDamage int?
Heavy attack damage.
final
heavySlamAttack int?
Heavy slam attack damage.
final
heavySlamRadialDamage int?
Radial damage for heavy attacks.
final
heavySlamRadius int?
Heavy slam attack radius.
final
imageName String?
Item image name.
finalinherited
maxLevelCap int
Max rank this weapon can be leveled
finalinherited
name String
Name of the item.
finalinherited
omegaAttenuation double
(?)
finalinherited
patchlogs List<Patchlog>?
Item changes throughout game version.
finalinherited
polarities List<String>?
Preinstalled polarities.
finalinherited
procChance double
Status chance.
finalinherited
productCategory String?
Item product category.
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setteroverride
range double?
Melee range.
final
releaseDate String?
The date the item was released in game.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slamAttack int?
Slam attack damage.
final
slamRadialDamage int?
Slam attack radial damage.
final
slamRadius int?
Slam attack radius.
final
slideAttack int?
slide attack damage.
final
slot int?
Slot.
finalinherited
stancePolarity String?
Stance polarity.
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tags List<String>?
Tags.
finalinherited
totalDamage num
Total damage the Weapon has.
finalinherited
tradable bool
Whether this item is tradable or not.
finalinherited
type ItemType
Item type.
finalinherited
uniqueName String
Unique name used within the game.
finalinherited
wikiaThumbnail String?
Wikia Item thumbnail url.
finalinherited
wikiaUrl String?
Item wikia url.
finalinherited
windUp double?
Wind up time.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Creates a json map from the giving Item.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited