MeleeAttack class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

MeleeAttack({required String name, required num? speed, required num critChance, required num critMult, required num statusChance, required Damage damage, required String? slide, required Slam? slam})
const
MeleeAttack.fromJson(Map<String, dynamic> data)
Creates a MeleeAttack from Json map
factory

Properties

critChance num
Crit chance.
finalinherited
critMult num
Crit multiplier.
finalinherited
damage Damage
Shot Damage information.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
Attack name.
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slam Slam?
Slam damage.
final
slide String?
Slide damage.
final
speed num?
Attack speed.
finalinherited
statusChance num
Status chance.
finalinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Creeates a json from an Attack.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited