ProfileNotFound class

Thrown when a profile was not found

Implemented types

Constructors

ProfileNotFound(String playerId)
Thrown when a profile was not found
const

Properties

hashCode int
The hash code for this object.
no setterinherited
playerId String
The player ID that was not found.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited