Quest class

Quest description

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

Quest({required String uniqueName, required String name, required String? description, required ItemType type, required String category, required String? productCategory, required String? imageName, required bool tradable, required bool? excludeFromCodex, required List<Patchlog>? patchlogs, required String? releaseDate, required String? wikiaThumbnail, required String? wikiaUrl})
Quest description
const
Quest.fromJson(Map<String, dynamic> data)
Creates a Quest from Json map
factory

Properties

category String
Item category.
finalinherited
description String?
Item decription.
finalinherited
excludeFromCodex bool?
Whether the item is excluded from the codex or not.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
imageName String?
Item image name.
finalinherited
name String
Name of the item.
finalinherited
patchlogs List<Patchlog>?
Item changes throughout game version.
finalinherited
productCategory String?
Item product category.
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
releaseDate String?
The date the item was released in game.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
tradable bool
Whether this item is tradable or not.
finalinherited
type ItemType
Item type.
finalinherited
uniqueName String
Unique name used within the game.
finalinherited
wikiaThumbnail String?
Wikia Item thumbnail url.
finalinherited
wikiaUrl String?
Item wikia url.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Creates a Json map from a Quest
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited