SteelPathReward class

Data about the a steel path reward.

Annotations
  • @JsonSerializable.new()

Constructors

SteelPathReward({required String name, required int cost})
Data about the a steel path reward.
const
SteelPathReward.fromJson(Map<String, dynamic> json)
Creates a SteelPathReward from a json map.
factory

Properties

cost int
Cost of the reward.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Item name of the reward.
final
props List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Creates a json map from SteelPathReward.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited