SyndicateJob class

Data on the current syndicate bounty.

Annotations
  • @JsonSerializable.new()

Constructors

SyndicateJob({required String id, required List<String> rewardPool, required List<RewardDrop>? rewardPoolDrops, required String? type, required List<int> enemyLevels, required List<int> standingStages, required int? minMr, required DateTime expiry})
Data on the current syndicate bounty.
const
SyndicateJob.fromJson(Map<String, dynamic> json)
Creates a Syndicatemission from Json map
factory

Properties

enemyLevels List<int>
Range of enemy level.
final
expiry DateTime
The time the job will expire on.
final
hashCode int
The hash code for this object.
no setterinherited
id String
Job id.
final
minMr int?
Minimum mastery rank needed to take job.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
rewardPool List<String>
Reward pool for the given job.
final
rewardPoolDrops List<RewardDrop>?
More verbose version of rewardPool with drop chance and item count
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
standingStages List<int>
Standing earned per stage.
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setter
type String?
Job type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Creates a Json map from a SyndicateJob
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited