SynthTargetClient class

Synthesis target client

Inheritance

Constructors

SynthTargetClient({Client? client, Language language = Language.en, String? ua})

Properties

hashCode int
The hash code for this object.
no setterinherited
language Language
The language that all request will be made for.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ua String?
Custom user agent.
finalinherited

Methods

fetchTargets() Future<List<SynthTarget>>
Retrives a list of all synthesis target.
get(String path, {Map<String, dynamic>? query}) Future<Response>
Fetches Warframestat API endpoint.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited