WorldstateObject class abstract

Base class for objects that come from the worldstate.

Not all classes extend/implement this class but the majority do.

Implementers
Annotations
  • @immutable

Constructors

WorldstateObject({String? id, DateTime? activation, DateTime? expiry})
Base class for objects that come from the worldstate.
const

Properties

activation DateTime?
The time the state was activated.
final
active bool
Whether or not the object was active after it was created.
no setter
expiry DateTime?
The time the state will expire.
final
hashCode int
The hash code for this object.
no setterinherited
id String?
ID of the instance.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
remaining Duration?
The remaining time until the state expires.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited