Arbitration class
Details of the currently active Arbitration.
- Inheritance
-
- Object
- WorldstateObject
- Arbitration
- Annotations
-
- @JsonSerializable.new()
- @experimental
Constructors
- Arbitration({required String? id, required DateTime activation, required DateTime expiry, required String node, required String nodeKey, required String? enemy, required String type, required String typeKey, required bool? archwing, required bool? sharkwing, required bool expired})
-
Details of the currently active Arbitration.
const
-
Arbitration.fromJson(Map<
String, dynamic> json) -
Creates a Arbitration from Json map
factory
Properties
- activation → DateTime
-
The time the state was activated.
no setteroverride
- active → bool
-
Whether or not the object was active after it was created.
no setterinherited
- archwing → bool?
-
Arbitration requires an archwing.
final
- enemy → String?
-
The faction the player will be facing.
final
- expired → bool
-
Whether the object is expired at the time of creation.
final
- expiry → DateTime
-
The time the state will expire.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
ID of the instance.
finalinherited
- node → String
-
The node the arbitration is taking place in.
final
- nodeKey → String
-
The untranslated node.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- remaining → Duration?
-
The remaining time until the state expires.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
Arbitration requires an archwing for swimming.
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - type → String
-
Arbitration mission type (localized).
final
- typeKey → String
-
Arbitration mission type.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Creates a Json map from a Arbitration.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited