Damage class
Damage information on Weapon
- Annotations
-
- @JsonSerializable.new()
Constructors
- Damage({required num total, required num impact, required num puncture, required num slash, required num heat, required num cold, required num electricity, required num toxin, required num blast, required num radiation, required num gas, required num magnetic, required num viral, required num corrosive, required num voidDamage, required num tau, required num cinematic, required num shieldDrain, required num healthDrain, required num energyDrain, required num trueDamage})
-
Damage information on Weapon
const
-
Damage.fromJson(Map<
String, dynamic> json) -
Creates Damage from json map.
factory
Properties
- blast → num
-
Blast damage.
final
- cinematic → num
-
Movie magic damage(?)
final
- cold → num
-
Cold damage.
final
- corrosive → num
-
Corrosive damage.
final
- electricity → num
-
Electric damage.
final
- energyDrain → num
-
Energy drain.
final
- gas → num
-
Gas damage.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthDrain → num
-
Health drain.
final
- heat → num
-
Heat damage
final
- impact → num
-
Impact damage.
final
- magnetic → num
-
Magnetic damage.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- puncture → num
-
Puncture damage.
final
- radiation → num
-
Radiation damage.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shieldDrain → num
-
Shield drain.
final
- slash → num
-
Slash damage.
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - tau → num
-
Tau damage
final
- total → num
-
Totla damage.
final
- toxin → num
-
Toxin damage.
final
- trueDamage → num
-
Raw damage.
final
-
Viral damage.
final
- voidDamage → num
-
Void damage.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Creates json map from Damage.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited