FlashSale class
FlashSale description
- Inheritance
-
- Object
- WorldstateObject
- FlashSale
- Annotations
-
- @JsonSerializable.new()
Constructors
- FlashSale({required String id, required DateTime activation, required DateTime expiry, required String item, required int? discount, required int? regularOverride, bool isPopular = false, bool isFeatured = false, bool isShownInMarket = false})
-
FlashSale description
const
-
FlashSale.fromJson(Map<
String, dynamic> json) -
Creates a FlashSale from Json map
factory
Properties
- activation → DateTime
-
The time the state was activated.
no setteroverride
- active → bool
-
Whether or not the object was active after it was created.
no setterinherited
- discount → int?
-
The discount percentage
final
- expiry → DateTime
-
The time the state will expire.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
ID of the instance.
no setteroverride
- isFeatured → bool
-
A description for isFeatured
final
- isPopular → bool
-
A description for isPopular
final
- isShownInMarket → bool
-
Whether or not the item is visible the in-game market
final
- item → String
-
Item on sale
final
-
The discounted platinum price
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- regularOverride → int?
-
The item's discounted credit price
final
- remaining → Duration?
-
The remaining time until the state expires.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Creates a Json map from a FlashSale
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited