GearBuildable class
Warframe gear.
- Inheritance
-
- Object
- Item
- EquipableItem
- BuildableItem
- GearBuildable
- Implemented types
- Annotations
-
- @JsonSerializable.new()
Constructors
-
GearBuildable({required String uniqueName, required String name, required String? description, required ItemType type, required String category, required String? productCategory, required bool tradable, required List<
Patchlog> ? patchlogs, required int buildPrice, required int buildQuantity, required int buildTime, required int skipBuildTimePrice, required bool consumeOnBuild, required String imageName, required bool isPrime, required List<Component> ? components, required bool? vaulted, required int? masteryReq, required String? releaseDate, required int? marketCost, required int? bpCost, required int? itemCount, required String? wikiaThumbnail, required String? wikiaUrl}) -
Warframe gear.
const
-
GearBuildable.fromJson(Map<
String, dynamic> json) -
Creates Gear from a json map.
factory
Properties
- bpCost → int?
-
Price of blueprint;
finalinherited
- buildPrice → int
-
The credit price to start building.
finalinherited
- buildQuantity → int
-
Amount of Items built per blueprint.
finalinherited
- buildTime → int
-
Time it takes for the build to finish.
finalinherited
- category → String
-
Item category.
finalinherited
-
components
→ List<
Component> ? -
List of components.
finalinherited
- consumeOnBuild → bool
-
Whether the blueprint is consumed after building.
finalinherited
- description → String?
-
Item decription.
finalinherited
- excludeFromCodex → bool?
-
Whether the item is excluded from the codex or not.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageName → String?
-
Item image name.
finalinherited
- isPrime → bool
-
Whether the Item is a prime item.
finalinherited
- itemCount → int?
-
Item count.
finalinherited
- marketCost → int?
-
Platnuim price in the warframe market.
finalinherited
- masteryReq → int?
-
Mastery requirement needed to build item.
finalinherited
- name → String
-
Name of the item.
finalinherited
-
patchlogs
→ List<
Patchlog> ? -
Item changes throughout game version.
finalinherited
- productCategory → String?
-
Item product category.
finalinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- releaseDate → String?
-
The date the item was released in game.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipBuildTimePrice → int
-
Platnuim needed to skip buildTime.
finalinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - tradable → bool
-
Whether this item is tradable or not.
finalinherited
- type → ItemType
-
Item type.
finalinherited
- uniqueName → String
-
Unique name used within the game.
finalinherited
- vaulted → bool?
-
Whether the Item has been removed from the drop rotation.
finalinherited
- wikiaThumbnail → String?
-
Wikia Item thumbnail url.
finalinherited
- wikiaUrl → String?
-
Item wikia url.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Creates a json map from Gear.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited