Invasion class
Invasion description
- Inheritance
-
- Object
- WorldstateObject
- Invasion
- Annotations
-
- @JsonSerializable.new()
Constructors
-
Invasion({required String id, required DateTime activation, required InvasionFaction attacker, required String attackingFaction, required bool completed, required num completion, required int count, required InvasionFaction defender, required String desc, required String node, required String nodeKey, required int requiredRuns, required List<
String> rewardTypes, required bool vsInfestation, required String eta}) -
Invasion description
const
-
Invasion.fromJson(Map<
String, dynamic> json) -
Creates a Invasion from Json map
factory
Properties
- activation → DateTime
-
The time the state was activated.
no setteroverride
- attacker → InvasionFaction
-
A description for attacker
final
- attackingFaction → String
-
A description for attackingFaction
final
- completed → bool
-
A description for completed
final
- completion → num
-
A description for completion
final
- count → int
-
A description for count
final
- defender → InvasionFaction
-
A description for defender
final
- desc → String
-
A description for desc
final
- eta → String
-
An estimated time the Invasion will end.
final
- expiry → DateTime?
-
The time the state will expire.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
ID of the instance.
no setteroverride
- node → String
-
A description for node
final
- nodeKey → String
-
A description for nodeKey
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setteroverride
- remaining → Duration?
-
The remaining time until the state expires.
no setterinherited
- requiredRuns → int
-
A description for requiredRuns
final
-
rewardTypes
→ List<
String> -
A description for rewardTypes
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - vsInfestation → bool
-
A description for vsInfestation
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Creates a Json map from a Invasion
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited