ItemType enum
Item cateogry types.
Values
- warframes → const ItemType
-
Warframe category.
const ItemType('Warframe') - melee → const ItemType
-
Melee category.
const ItemType('Melee') - archMelee → const ItemType
-
Arch-Melee category.
const ItemType('Arch-Melee') - archGun → const ItemType
-
Arch-Gun category.
const ItemType('Arch-Gun') - resources → const ItemType
-
Resource category.
const ItemType('Resource') - skin → const ItemType
-
Skins category.
const ItemType('Skin') - gear → const ItemType
-
Gear category.
const ItemType('Gear') - arcanes → const ItemType
-
Arcanes category.
const ItemType('Arcane') - archwing → const ItemType
-
Archwing category.
const ItemType('Archwing') - fish → const ItemType
-
Fish category.
const ItemType('Fish') - glyphs → const ItemType
-
Glyphs category.
const ItemType('Glyph') - misc → const ItemType
-
Misc category.
const ItemType('Misc') - node → const ItemType
-
Node category.
const ItemType('Node') - quests → const ItemType
-
Quests category.
const ItemType('Quest') - relics → const ItemType
-
Relics category.
const ItemType('Relic') - petResource → const ItemType
-
Pet Resource category.
const ItemType('Pet Resource') - sigils → const ItemType
-
Sigils category.
const ItemType('Sigil') - pets → const ItemType
-
Pets category.
const ItemType('Pets') - sentinels → const ItemType
-
Sentinel category.
const ItemType('Sentinel') - necramechMod → const ItemType
-
Necramech Mod
const ItemType('Necramech Mod') - primaryMod → const ItemType
-
Mods for primary weapons
const ItemType('Primary Mod') - secondaryMod → const ItemType
-
Mods for secondary weapons
const ItemType('Secondary Mod') - warframeMod → const ItemType
-
Mods for Warframes.
const ItemType('Warframe Mod') - shotGunMod → const ItemType
-
Mods for shotguns.
const ItemType('Shotgun Mod') - companionMod → const ItemType
-
Mods for companions.
const ItemType('Companion Mod') - archwingMod → const ItemType
-
Mods for Archwing
const ItemType('Archwing Mod') - archMeleeMod → const ItemType
-
Arch-Melee Mod
const ItemType('Arch-Melee Mod') - archGunMod → const ItemType
-
Arch-Gun Mod
const ItemType('Arch-Gun Mod') - stanceMod → const ItemType
-
Stance Mod
const ItemType('Stance Mod') - parazonMod → const ItemType
-
Parazon Mod
const ItemType('Parazon Mod') - kDriveMod → const ItemType
-
K-Drive Mod
const ItemType('K-Drive Mod') - meleeMod → const ItemType
-
Melee Mod
const ItemType('Melee Mod') - peculiarMod → const ItemType
-
Peculiar Mod
const ItemType('Peculiar Mod') - companionWeaponRiven → const ItemType
-
Companion Weapon Riven Mod
const ItemType('Companion Weapon Riven Mod') - archGunRiven → const ItemType
-
Arch-Gun Riven Mod
const ItemType('Arch-Gun Riven Mod') - rifleRiven → const ItemType
-
Rifle Riven Mod
const ItemType('Rifle Riven Mod') - pistolRiven → const ItemType
-
Pistol Riven Mod
const ItemType('Pistol Riven Mod') - shotgunRiven → const ItemType
-
Shotgun Riven Mod
const ItemType('Shotgun Riven Mod') - meleeRiven → const ItemType
-
Melee Riven Mod
const ItemType('Melee Riven Mod') - kitgunRiven → const ItemType
-
Kitgun Riven Mod
const ItemType('Kitgun Riven Mod') - zawRiven → const ItemType
-
Zaw Riven Mod
const ItemType('Zaw Riven Mod') - rivenMod → const ItemType
-
Riven Mod
const ItemType('Riven Mod') - shotgun → const ItemType
-
Shotgun
const ItemType('Shotgun') - rifle → const ItemType
-
Rifles
const ItemType('Rifle') - pistol → const ItemType
-
Pistols
const ItemType('Pistol') - companionWeapon → const ItemType
-
Companion weapon
const ItemType('Companion Weapon') - dualPistols → const ItemType
-
Dual Pistols
const ItemType('Dual Pistols') - throwing → const ItemType
-
Throwing weapons
const ItemType('Throwing') - amp → const ItemType
-
Amp
const ItemType('Amp') - kDriveComponent → const ItemType
-
K-Drive Component
const ItemType('K-Drive Component') - zawComponent → const ItemType
-
Zaw Component
const ItemType('Zaw Component') - kitGunComponent → const ItemType
-
Kitgun Component
const ItemType('Kitgun Component')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isMelee → bool
-
Whether the type is a melee weapon or not
no setter
- isPrimary → bool
-
Whether the type is a primary weapon or not
no setter
- isSecondary → bool
-
Whether the type is a secondary weapon or not
no setter
- isWeapon → bool
-
Whether the type is a weapon or not
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Item Category name.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited