ProfileMission class
Nodes/Missions completed
- Annotations
-
- @JsonSerializable.new()
Constructors
- ProfileMission({required String node, required String nodeKey, required String? missionType, required String? faction, required int? highScore, required int? completes, required int? tier})
-
Nodes/Missions completed
const
-
ProfileMission.fromJson(Map<
String, dynamic> json) -
Get ProfileMission from json
factory
Properties
- completes → int?
-
Number of completions
final
- faction → String?
-
Node faction occupenc
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highScore → int?
-
High score
final
- missionType → String?
-
Node mission type
final
- node → String
-
Node name
final
- nodeKey → String
-
Node uniqueName
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - tier → int?
-
Mission tier
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Creates a json map from ProfileMission
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited