Reward class
Contains data about a given reward.
- Annotations
-
- @JsonSerializable.new()
Constructors
-
Reward({required List<
String> items, required List<CountedItem> countedItems, required int credits, required String asString, required String itemString, required String thumbnail, required int color}) -
Contains data about a given reward.
const
-
Reward.fromJson(Map<
String, dynamic> json) -
Creates a Reward from json map.
factory
Properties
- asString → String
-
Reward as a string.
final
- color → int
-
Item color.
final
-
countedItems
→ List<
CountedItem> -
The counted items being rewarded.
final
- credits → int
-
The credits being rewarded.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
String> -
Items being awarded.
final
- itemString → String
-
Item as a string.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - thumbnail → String
-
Item thumnail.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Creates a json map from Reward.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited